@@ -26,16 +26,26 @@
 #define DEFAULT_NUMBER_FORMAT  0
 #define DEFAULT_PAGE_NUMBER    0
 #define DEFAULT_Y              0
+#define DEFAULT_FULL_SCREEN    false
+#define DEFAULT_ORIENTATION    1
 
-#define FONT_FAMILY            "me_quran"
+#define FONT_FAMILY            "Scheherazade"
 #define FONT_MIN_SIZE          16
 #define FONT_MAX_SIZE          48
 #define HIGHLIGHT_COLOR        QColor(163, 218, 244)
-
-#define FONT_FILE              "me_quran_volt_newmet.ttf"
+#define TITLE_COLOR            Qt::black
+#define SUBTITLE_COLOR         Qt::black
+#define VERSE_COLOR            Qt::black
+#define FONT_FILE              "ScheherazadeRegOT.ttf"
 
 Q_DECLARE_METATYPE(QList<uint>);
 
+/*!
+ * Orientations:
+ * 0 = Automatic
+ * 1 = Portrait
+ * 2 = Landscape
+ */
 Settings::Settings(QObject *parent) : QObject(parent), m_font(-1) {
   qRegisterMetaType<QList<uint> >("QList<uint>");
   qRegisterMetaTypeStreamOperators<QList<uint> >("QList<uint>");
@@ -120,6 +130,18 @@ QColor Settings::highlightColor() const {
   return HIGHLIGHT_COLOR;
 }
 
+QColor Settings::verseColor() const {
+  return VERSE_COLOR;
+}
+
+QColor Settings::titleColor() const {
+  return TITLE_COLOR;
+}
+
+QColor Settings::subtitleColor() const {
+  return SUBTITLE_COLOR;
+}
+
 QString Settings::version() const {
   return VERSION;
 }
@@ -136,17 +158,6 @@ bool Settings::isFontLoaded() const {
   return m_font != -1;
 }
 
-void Settings::setPosition(const QPoint& pos) {
-  if (pos != position()) {
-    m_settings->setValue("General/position", pos);
-    emit positionChanged();
-  }
-}
-
-QPoint Settings::position() const {
-  return m_settings->value("General/position", QPoint(0, 0)).toPoint();
-}
-
 int Settings::y() const {
   return m_settings->value("General/y", DEFAULT_Y).toInt();
 }
@@ -157,3 +168,35 @@ void Settings::setY(int y) {
     emit yChanged();
   }
 }
+
+void Settings::setFullScreen(bool fs) {
+  if (fullScreen() != fs) {
+    m_settings->setValue("General/fullScreen", fs);
+    emit fullScreenChanged();
+  }
+}
+
+bool Settings::fullScreen() const {
+  return m_settings->value("General/fullScreen", DEFAULT_FULL_SCREEN).toBool();
+}
+
+void Settings::setOrientation(int orientation) {
+  int o = qBound(0, orientation, 2);
+  if (Settings::orientation() != o) {
+    m_settings->setValue("General/orientation", o);
+    emit orientationChanged();
+  }
+}
+
+int Settings::orientation() const {
+  return qBound(0, m_settings->value("General/orientation", DEFAULT_ORIENTATION).toInt(), 2);
+}
+
+void Settings::reset() {
+  setFullScreen(DEFAULT_FULL_SCREEN);
+  setOrientation(DEFAULT_ORIENTATION);
+  setFontSize(DEFAULT_FONT_SIZE);
+  setNumberFormat(DEFAULT_NUMBER_FORMAT);
+  setTextType(DEFAULT_TEXT_TYPE);
+  setY(DEFAULT_Y);
+}
